Summary:        A gesture-recognition application for X11
Name:           easystroke
Version:        0.6.0
Release:        %mkrel 16
Group:          Accessibility
License:        ISC
Url:            http://easystroke.sourceforge.net/
Source0:        http://downloads.sourceforge.net/easystroke/%{name}-%{version}.tar.gz
Patch0:         easystroke-0.6.0-fix-desktop-file.patch
# fix build with libsigc++ 2.6; also build in C++11 mode
# (not sure if the lambda is correct, but seems to work)
Patch1:         replace-sigc-group-with-lambda.patch
# https://github.com/thjaeger/easystroke/pull/8
Patch3:		easystroke-0.6.0-abs.patch
BuildRequires:  pkgconfig(gdkmm-3.0)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(xorg-server)
BuildRequires:  boost-devel
BuildRequires:  intltool
BuildRequires:  help2man

%description
Easystroke is a gesture-recognition application for X11. Gestures or
strokes are movements that you make with you mouse (or your pen,
finger etc.) while holding down a specific mouse button. Easystroke
will execute certain actions if it recognizes the stroke; currently
easystroke can emulate key presses, execute shell commands, hold down
modifiers and emulate a scroll wheel.
The program was designed with Tablet PCs in mind and can be used
effectively even without access to a keyboard. Easystroke tries to
provide an intuitive and efficient user interface, while at the same
time being highly configurable and offering many advanced features.

%prep
%setup -q
%autopatch -p1

# fix PREFIX
sed -i -e 's:/usr/local:%{_prefix}:' Makefile
# do not strip binary
sed -i -e 's:install -Ds:install -D:g' Makefile

%build
%make_build	CXX="g++ %{optflags}" \
		CC="gcc -std=c99 %{optflags}" \
		LDFLAGS="%{ldflags}"

# man page
make man

%install
%make_install

# man page install
install -D -m644 %{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1

%find_lang %{name}

%files -f %{name}.lang
%doc LICENSE changelog
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_mandir}/man1/%{name}*


%changelog
* Thu Dec 31 2020 wally <wally> 0.6.0-16.mga8
+ Revision: 1666748
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 0.6.0-15.mga8
+ Revision: 1661990
- rebuild for boost 1.74.0

* Sun May 03 2020 wally <wally> 0.6.0-14.mga8
+ Revision: 1578044
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 0.6.0-13.mga8
+ Revision: 1544678
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 0.6.0-12.mga8
+ Revision: 1483357
- rebuild for boost 1.72.0

* Tue Oct 16 2018 wally <wally> 0.6.0-11.mga7
+ Revision: 1321025
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 0.6.0-10.mga7
+ Revision: 1297547
- Mageia 7 Mass Rebuild

* Mon Dec 25 2017 wally <wally> 0.6.0-9.mga7
+ Revision: 1184744
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 0.6.0-8.mga7
+ Revision: 1178315
- rebuild for boost 1.65

* Sun Sep 17 2017 daviddavid <daviddavid> 0.6.0-7.mga7
+ Revision: 1154984
- add fedora patch to fix build with gcc7
+ tv <tv>
- rebuild with latest boost

* Mon Jan 11 2016 daviddavid <daviddavid> 0.6.0-6.mga6
+ Revision: 921628
- add patch1 from Arch Linux to fix build with libsigc++ 2.6 and also to build in C++11 mode
- do not strip binary to fix empty debuginfo
- rebuild for new boost 1.59.0

* Wed Oct 15 2014 umeabot <umeabot> 0.6.0-5.mga5
+ Revision: 745579
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.6.0-4.mga5
+ Revision: 678912
- Mageia 5 Mass Rebuild

* Sat Feb 08 2014 barjac <barjac> 0.6.0-3.mga5
+ Revision: 586451
- rebuild against boost-1.55

* Sat Oct 19 2013 umeabot <umeabot> 0.6.0-2.mga4
+ Revision: 533129
- Mageia 4 Mass Rebuild

* Mon Aug 26 2013 stormi <stormi> 0.6.0-1.mga4
+ Revision: 471851
- new patch to fix desktop file, upstream one still has issues
- really delete old patch
- update to 0.6.0
- remove no more needed patch

* Tue Jul 09 2013 fwang <fwang> 0.5.6-4.mga4
+ Revision: 451762
- rebuild for new boost

* Thu Apr 11 2013 barjac <barjac> 0.5.6-3.mga3
+ Revision: 409525
- rebuild for boost-1.53

* Fri Jan 11 2013 umeabot <umeabot> 0.5.6-2.mga3
+ Revision: 349286
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 stormi <stormi> 0.5.6-1.mga3
+ Revision: 339882
- try to fix desktop-file again
- fix desktop file
- new version 0.5.6

* Thu Dec 20 2012 fwang <fwang> 0.5.5.1-5.mga3
+ Revision: 333015
- rebuild for new boost

* Fri Aug 03 2012 fwang <fwang> 0.5.5.1-4.mga3
+ Revision: 278093
- rebuild for new boost

* Wed May 30 2012 fwang <fwang> 0.5.5.1-3.mga3
+ Revision: 249688
- rebuild for new boost

* Mon Nov 28 2011 fwang <fwang> 0.5.5.1-2.mga2
+ Revision: 173555
- rebuild for new boost

* Sat Sep 24 2011 stormi <stormi> 0.5.5.1-1.mga2
+ Revision: 147557
- new version 0.5.5.1
+ fwang <fwang>
- br xserver
- rebuild for new boost

* Wed Jun 22 2011 fwang <fwang> 0.5.4-2.mga2
+ Revision: 111875
- rebuild for new boost

* Fri Mar 11 2011 stormi <stormi> 0.5.4-1.mga1
+ Revision: 68085
- new version 0.5.4

* Fri Mar 11 2011 stormi <stormi> 0.5.3-2.mga1
+ Revision: 68066
- imported package easystroke


* Mon Aug 23 2010 Funda Wang <fwang@mandriva.org> 0.5.3-2mdv2011.0
+ Revision: 572153
- rebuild for new boost

* Sun Feb 14 2010 Jérôme Brenier <incubusss@mandriva.org> 0.5.3-1mdv2011.0
+ Revision: 505851
- add a precison : x11-server-devel >= 1.7

* Sun Feb 14 2010 Jérôme Brenier <incubusss@mandriva.org> 0.5.3-1mdv2010.1
+ Revision: 505618
- new version 0.5.3
- drop Patch0 (merged upstream)

* Mon Feb 08 2010 Anssi Hannula <anssi@mandriva.org> 0.5.2-3mdv2010.1
+ Revision: 501882
- rebuild for new boost

* Fri Feb 05 2010 Jérôme Brenier <incubusss@mandriva.org> 0.5.2-2mdv2010.1
+ Revision: 501026
- rebuild

  + Funda Wang <fwang@mandriva.org>
    - BR x11 server
    - New version 0.5.2
    - rebuild for new boost

* Wed Dec 23 2009 Jérôme Brenier <incubusss@mandriva.org> 0.4.10-2mdv2010.1
+ Revision: 481773
- buildrequires help2man
- add the man page

* Wed Dec 23 2009 Jérôme Brenier <incubusss@mandriva.org> 0.4.10-1mdv2010.1
+ Revision: 481639
- import easystroke


